Arrow class

Constructors

Arrow(double sx, double sy, double cx, double cy, double ex, double ey)

Properties

cx → double
The x position of the (padded) starting point.
final
cy → double
The x position of the (padded) starting point.
final
ex → double
The x position of the (padded) starting point.
final
ey → double
The x position of the (padded) starting point.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sx → double
The x position of the (padded) starting point.
final
sy → double
The x position of the (padded) starting point.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited